Module: WhatsUp
- Defined in:
- lib/whats_up.rb,
lib/whats_up/classic.rb,
lib/whats_up/methods.rb,
lib/whats_up/version.rb,
lib/whats_up/dummy_out.rb,
lib/whats_up/method_finder.rb,
lib/whats_up/frozen_section.rb
Overview
whats_up enables you to determine what methods can be called on an object that return a given value
Some credits from Dr. Nic
Code this version is based on: Andrew Birkett's
Improvements from Why's blog entry:
what?- Why- @@blacklist - llasram
clonealias - Daniel Schierbeck- $stdout redirect - Why
Improvements from Nikolas Coukouma
- Varargs and block support
- Improved catching
- Redirecting $stdout and $stderr (independently of Why)
A version posted in 2002 by Steven Grady
David Tran's versions:
Defined Under Namespace
Modules: Classic, Methods Classes: DummyOut, FrozenSection, MethodFinder
Constant Summary collapse
- VERSION =
The current version
"1.2.2"